<template>
    <div class="system-role-container">
        <el-card shadow="hover">
            <div class="system-user-search mb15">
                <div class="basic-line">
                    <span>整改类型：</span>
                    <el-select class="input-box" v-model="rectifyData.params.rectifyType" placeholder="整改类型" filterable>
                        <el-option v-for="item in rectifyTypeList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                    </el-select>
                </div>
                <div class="basic-line">
                    <span>整改部门：</span>
                    <el-cascader :options="departmentList" :props="{ emitPath: false, checkStrictly: true, value: 'depId', label: 'depName' }" placeholder="请选择部门" clearable filterable class="input-box" v-model="rectifyData.params.rectifyDepId"> </el-cascader>
                </div>

                <el-button size="default" type="primary" class="ml10" v-throttle @click="handleSearch">
                    <el-icon>
                        <ele-Search />
                    </el-icon>
                    查询
                </el-button>
            </div>
            <el-table :data="rectifyData.data" style="width: 100%" fit highlight-current-row>
                <el-table-column type="index" label="序号" width="60" />
                <el-table-column prop="rectifyDesc" label="整改内容说明" show-overflow-tooltip></el-table-column>
                <el-table-column prop="rectifyTime" label="整改期限" min-width="130px" show-overflow-tooltip>
                    <template #default="scope">
                        <span>{{ scope.row.rectifyTime }}</span>
                        <span v-if="scope.row.dangerStatus === 2" class="overdue-img">逾期</span>
                        <span v-if="scope.row.dangerStatus === 9" class="overdue-img">逾期</span>
                    </template>
                </el-table-column>
                <el-table-column prop="rectifyType" label=" 整改类型" show-overflow-tooltip>
                    <template #default="scope">
                        {{ parseNumber(scope.row.rectifyType, '整改类型') }}
                    </template>
                </el-table-column>
                <el-table-column prop="liablePerson" label="整改责任人" show-overflow-tooltip></el-table-column>
                <el-table-column prop="cost" label="整改资金" show-overflow-tooltip></el-table-column>
                <el-table-column prop="dangerStatus" label="隐患整改状态" show-overflow-tooltip align="center">
                    <template #default="scope">
                        <el-tag :type="scope.row.dangerStatus === 0 ? 'info' : scope.row.dangerStatus === 1 ? 'primary' : scope.row.dangerStatus === 2 ? 'warning' : scope.row.dangerStatus === 4 ? 'danger' : 'success'">
                            {{ parseNumber(scope.row.dangerStatus, '隐患整改状态') }}
                        </el-tag>
                    </template>
                </el-table-column>
                <el-table-column prop="createByUserName" label="创建人" show-overflow-tooltip></el-table-column>
                <el-table-column prop="gmtCreate" label="创建时间" show-overflow-tooltip></el-table-column>
                <el-table-column prop="lastEditUserName" label="最后修改人" show-overflow-tooltip></el-table-column>
                <el-table-column prop="gmtModitify" label="最后修改时间" show-overflow-tooltip></el-table-column>
                <el-table-column label="操作" width="250" fixed="right" align="center">
                    <template #default="scope">
                        <el-button size="small" text type="primary" :icon="View" @click="onOpenDialogRef('查看', scope.row)">查看</el-button>
                        <el-button size="small" text type="primary" :icon="Check" v-show="scope.row.dangerStatus === 0 || scope.row.dangerStatus === 2" @click="onOpenDialogRef('整改', scope.row)">整改</el-button>
                        <el-button size="small" text type="primary" :icon="Edit" v-show="scope.row.dangerStatus === 0 || scope.row.dangerStatus === 2" @click="onOpenDialogRef('延期', scope.row)">延期</el-button>
                        <el-button size="small" text type="danger" :icon="Delete" @click="onDelHiddenRectify(scope.row)">删除</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br />
            <el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" :pager-count="5" :page-sizes="[10, 20, 30]" v-model:current-page="rectifyData.params.pageIndex" background v-model:page-size="rectifyData.params.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="rectifyData.total" class="page-position"> </el-pagination>
            <br />
            <br />
        </el-card>
        <rectifyDialog ref="rectifyDialogRef" @refreshRectify="initRectifyTableData" />
    </div>
</template>

<script lang="ts">
import { toRefs, reactive, onMounted, ref, defineComponent } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import rectifyDialog from './components/rectifyDialog.vue';
import { Edit, Delete, Check, View } from '@element-plus/icons-vue';
import { hiddenRectifyApi } from '/@/api/doublePreventSystem/rectify';
import { departmentApi } from '/@/api/systemManage/department';
import { productionDeviceApi } from '/@/api/doublePreventSystem/productionDevice';

// 定义接口来定义对象的类型
interface TableData {
    quota: string;
    quotaUnit: string;
    quotaType: string;
    createUserName: string;
    gmtCreate: string;
    lastEditUserName: string;
    gmtModitify: string;
}
interface TableDataState {
    rectifyData: {
        data: Array<TableData>;
        total: number;
        loading: boolean;
        params: {
            pageIndex: number;
            pageSize: number;
            rectifyType: number | null;
            rectifyDepId: number | null;
            dangerStatus: number | null;
        };
    };
    rectifyTypeList: Array<enumType>;
    dangerStatusList: Array<enumType>;
    departmentList: [];
}
interface enumType {
    id: number;
    name: string;
}

export default defineComponent({
    name: 'rectify',
    components: { rectifyDialog, Edit, Delete, View },
    setup() {
        const rectifyDialogRef = ref();
        const state = reactive<TableDataState>({
            rectifyData: {
                data: [],
                total: 0,
                loading: false,
                params: {
                    pageIndex: 1,
                    pageSize: 10,
                    rectifyType: null,
                    rectifyDepId: null,
                    dangerStatus: null
                }
            },
            departmentList: [],
            rectifyTypeList: [
                { id: 1, name: '即查即改' },
                { id: 2, name: '限期整改' }
            ],
            dangerStatusList: [
                { id: 0, name: '整改中' },
                { id: 1, name: '待验收' },
                { id: 2, name: '延期整改' },
                { id: 4, name: '超期未整改' },
                { id: 9, name: '已验收' }
            ]
        });

        // 初始化表格数据
        const initRectifyTableData = async () => {
            let res = await hiddenRectifyApi().getHiddenRectifyList(state.rectifyData.params);
            if (res.data.code === '200') {
                state.rectifyData.data = res.data.data;
                state.rectifyData.total = res.data.count;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        //获取部门列表
        const getDepartmentData = async () => {
            let res = await departmentApi().getDepartmentList();
            if (res.data.code === '200') {
                state.departmentList = res.data.data;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        // 打开弹窗
        const onOpenDialogRef = (type: string, value: any) => {
            rectifyDialogRef.value.openRectifyDialog(type, value, state.departmentList);
        };
        // 删除
        const onDelHiddenRectify = (row: any) => {
            ElMessageBox.confirm(`此操作将永久删除该隐患整改，是否继续?`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            })
                .then(async () => {
                    let res = await hiddenRectifyApi().deleteHiddenRectify({ id: row.id });
                    if (res.data.code === '200') {
                        ElMessage({
                            type: 'success',
                            duration: 2000,
                            message: '删除成功'
                        });
                        await initRectifyTableData();
                    } else {
                        ElMessage({
                            type: 'warning',
                            message: res.data.msg
                        });
                    }
                })
                .catch(() => {});
        };

        const parseNumber = (value: string | number, type: string) => {
            if (type === '整改类型') {
                return state.rectifyTypeList.find((item) => item.id === value)?.name;
            } else if (type === '隐患整改状态') {
                return state.dangerStatusList.find((item) => item.id === value)?.name;
            }
        };

        const handleSearch = () => {
            initRectifyTableData();
        };
        // 分页改变
        const onHandleSizeChange = (val: number) => {
            state.rectifyData.params.pageSize = val;
            initRectifyTableData();
        };
        // 分页改变
        const onHandleCurrentChange = (val: number) => {
            state.rectifyData.params.pageIndex = val;
            initRectifyTableData();
        };
        // 页面加载时
        onMounted(() => {
            initRectifyTableData();
            getDepartmentData();
        });

        return {
            Edit,
            View,
            Check,
            Delete,
            parseNumber,
            handleSearch,
            onOpenDialogRef,
            onHandleSizeChange,
            onDelHiddenRectify,
            onHandleCurrentChange,
            rectifyDialog,
            rectifyDialogRef,
            initRectifyTableData,
            ...toRefs(state)
        };
    }
});
</script>

<style scoped>
.overdue-img {
    position: absolute;
    background-color: #f56c6c;
    border-radius: 4px;
    color: #fff;
    display: inline-block;
    font-size: 12px;
    height: 21px;
    line-height: 18px;
    text-align: center;
    white-space: nowrap;
    border: 1px solid #fff;
    transform: scale(0.8);
    padding: 1px 3px 0 3px;
}
:deep(.el-textarea.is-disabled .el-textarea__inner) {
    background-color: var(--el-card-bg-color);
    color: var(--el-input-text-color, var(--el-text-color-regular));
}
:deep(.el-input.is-disabled .el-input__inner) {
    color: var(--el-input-text-color, var(--el-text-color-regular));
}
:deep(.el-input.is-disabled .el-input__wrapper) {
    background-color: var(--el-card-bg-color);
}
</style>
